Free convection to enclosed bodies (ht.conv_free_enclosed)
==========================================================

.. automodule:: ht.conv_free_enclosed
    :members:
    :undoc-members:
    :show-inheritance:
